@@ -40,7 +40,7 @@ class Loader(threading.Thread):
 			print(f"{message} ... {color.red}failed{color.end}")
 
 # the loader object class.
-class ProgessLoader(threading.Thread):
+class ProgressLoader(threading.Thread):
 	def __init__(self, message, index=0, max=10):
 		threading.Thread.__init__(self)
 		self.message = message
@@ -50,12 +50,12 @@ class ProgessLoader(threading.Thread):
 		self.index = index
 		self.max = max
 		self.progress = None
-	def next(self, count=1):
+	def next(self, count=1, decimals=2):
 		self.index += count
-		p = round((self.index / self.max) * 100, 2)
+		p = round((self.index / self.max) * 100, decimals)
 		if p != self.progress:
 			self.progress = p
-			print(f"{self.message} ... {self.p}", end="\r")
+			print(f"{self.message} ... {self.progress}", end="\r")
 	def stop(self, message=None, success=True, response=None):
 		if response == None:
 			if message == None: message = self.message
