@@ -37,7 +37,11 @@ class Defaults(object):
 		alias=None, 
 		# the source path.
 		executable=None,
+		# can use sudo.
+		sudo=False,
 	):
+		if sudo: sudo = "sudo "
+		else: sudo = ""
 		present = "--create-alias" in sys.argv and get_argument("--create-alias") == alias
 		base = f"/usr/local/bin"
 		if not os.path.exists(base):
@@ -46,9 +50,9 @@ class Defaults(object):
 		if present or not os.path.exists(path):
 			#file = f"""package={executable}/\nargs=""\nfor var in "$@" ; do\n   	if [ "$args" == "" ] ; then\n   		args=$var\n   	else\n   		args=$args" "$var\n   	fi\ndone\npython3 $package $args\n"""
 			file = f"""#!/usr/bin/env python3\nimport os, sys\npackage="{executable}"\nsys.argv.pop(0)\narguments = sys.argv\ns = ""\nfor i in arguments:\n	if s == "": \n		if " " in i: s = "'"+i+"'"\n		else: s = i\n	else: \n		if " " in i: s += " '"+i+"'"\n		else: s += " "+i\nos.system("python3 "+package+" "+s)"""
-			os.system(f"touch {path}")
-			os.system(f"chmod +x {path}")
-			os.system(f"chown {self.user}:{self.group} {path}")
+			os.system(f"{sudo}touch {path}")
+			os.system(f"{sudo}chmod +x {path}")
+			os.system(f"{sudo}chown {self.user}:{self.group} {path}")
 			try:
 				Files.File(path=f"{path}", data=file).save()
 			except:
